ALTER TABLE DELAVCI
ADD ID_TIPSERVIS VARCHAR2(6 CHAR);

DROP VIEW V_DELAVCI;

CREATE OR REPLACE VIEW V_DELAVCI AS (
	SELECT D.ID_DELAVCI, D.ID_STORITVE, D.SIFRA, D.DATUM, D.STEVILO_UR, D.KOMENTAR,
  MNS.OPIS AS NNSTOMAR_OPIS, ND.OPIS AS NNDELAVC_OPIS, ND.INTERNI_OPIS AS NNDELAVC_INTERNI_OPIS, TS.OPIS AS TIPSERVIS_OPIS
  FROM DELAVCI D
  LEFT OUTER JOIN M_STORITVE MS ON MS.ID_STORITVE = D.ID_STORITVE
  LEFT OUTER JOIN M_NNSTOMAR MNS ON MNS.SIFRA = MS.STORITEV
  LEFT OUTER JOIN NNDELAVC ND ON ND.SIFRA = D.SIFRA
  LEFT OUTER JOIN TIPSERVIS TS ON TS.SIFRA = D.ID_TIPSERVIS
);

ALTER TABLE NNDELAVC
ADD TYPE NUMBER;

CREATE TABLE MAINTENANCE_TYPE (
  ID_MAINTENANCE_TYPE NUMBER NOT NULL,
  TYPE VARCHAR2(3 CHAR),
  DESCRIPTION VARCHAR2(200 CHAR),
  WORK_TIME_FROM VARCHAR2(10 CHAR),
  WORK_TIME_TO	VARCHAR2(10 CHAR),
  TIME_UNIT	VARCHAR2(20 CHAR),
  ACTIVE VARCHAR2(1 CHAR),
  CONSTRAINT MAINTENANCE_TYPE_PK PRIMARY KEY (ID_MAINTENANCE_TYPE)
);

CREATE SEQUENCE MAINTENANCE_TYPE_SEQ MINVALUE 1 INCREMENT BY 1 START WITH 1 NOCACHE NOORDER  NOCYCLE;

CREATE TABLE MAINTENANCE_STATUS (
  ID_MAINTENANCE_STATUS NUMBER NOT NULL,
  DESCRIPTION VARCHAR2(200 CHAR),
  COLOR VARCHAR2(20 CHAR),
  TEXT_COLOR VARCHAR2(20 CHAR),
  ACTIVE VARCHAR2(1 CHAR),
  CONSTRAINT MAINTENANCE_STATUS_PK PRIMARY KEY (ID_MAINTENANCE_STATUS)
);

INSERT INTO MAINTENANCE_STATUS(ID_MAINTENANCE_STATUS, DESCRIPTION, ACTIVE) VALUES
(-1, 'Cancelled', 'Y');

INSERT INTO MAINTENANCE_STATUS(ID_MAINTENANCE_STATUS, DESCRIPTION, ACTIVE) VALUES
(1, 'Open', 'Y');

INSERT INTO MAINTENANCE_STATUS(ID_MAINTENANCE_STATUS, DESCRIPTION, ACTIVE) VALUES
(2, 'Confirmed', 'Y');

INSERT INTO MAINTENANCE_STATUS(ID_MAINTENANCE_STATUS, DESCRIPTION, ACTIVE) VALUES
(3, 'Completed', 'Y');

CREATE SEQUENCE MAINTENANCE_STATUS_SEQ MINVALUE 1 INCREMENT BY 1 START WITH 20 NOCACHE NOORDER  NOCYCLE;

CREATE TABLE MAINTENANCE_TASK (
  ID_MAINTENANCE_TASK NUMBER NOT NULL,
  ID_TYPE NUMBER,
  ID_STATUS NUMBER,
  ID_ASSET NUMBER,
  ID_DN NUMBER,
  NNLOCATION_ID NUMBER,
  DATE_FROM DATE,
  DATE_TO DATE,
  "COMMENT" VARCHAR2(300 CHAR),
  CONSTRAINT MAINTENANCE_TASK_PK PRIMARY KEY (ID_MAINTENANCE_TASK),
  CONSTRAINT MAINTENANCE_TASK_TYPE_FK FOREIGN KEY (ID_TYPE) REFERENCES MAINTENANCE_TYPE(ID_MAINTENANCE_TYPE),
  CONSTRAINT MAINTENANCE_TASK_STATUS_FK FOREIGN KEY (ID_STATUS) REFERENCES MAINTENANCE_STATUS(ID_MAINTENANCE_STATUS),
  CONSTRAINT MAINTENANCE_TASK_ASSET_FK FOREIGN KEY (ID_ASSET) REFERENCES ASSET(ID_ASSET),
  CONSTRAINT MAINTENANCE_TASK_DN_FK FOREIGN KEY (ID_DN) REFERENCES M_DE_NA(ID_DN),
  CONSTRAINT MAINTENANCE_TASK_NNLOCATION_FK FOREIGN KEY (NNLOCATION_ID) REFERENCES NNLOCATION(ID)
);

CREATE INDEX IX_MAINTENANCE_TASK_ID_TYPE ON MAINTENANCE_TASK (ID_TYPE);
CREATE INDEX IX_MAINTENANCE_TASK_ID_STATUS ON MAINTENANCE_TASK (ID_STATUS);
CREATE INDEX IX_MAINTENANCE_TASK_ID_ASSET ON MAINTENANCE_TASK (ID_ASSET);
CREATE INDEX IX_MAINTENANCE_TASK_ID_DN ON MAINTENANCE_TASK (ID_DN);
CREATE INDEX IX_MAINTENANCE_TASK_NNLOC_ID ON MAINTENANCE_TASK (NNLOCATION_ID);

CREATE SEQUENCE MAINTENANCE_TASK_SEQ MINVALUE 1 INCREMENT BY 1 START WITH 1 NOCACHE NOORDER  NOCYCLE;


CREATE OR REPLACE VIEW V_MAINTENANCE_TASK AS (
SELECT M.ID_MAINTENANCE_TASK, M.ID_TYPE, M.ID_STATUS, M.ID_ASSET, M.ID_DN, M.NNLOCATION_ID, M.DATE_FROM, M.DATE_TO, M."COMMENT",
MT.DESCRIPTION AS TYPE_DESCRIPTION, MS.DESCRIPTION AS STATUS_DESCRIPTION, MS.COLOR AS STATUS_COLOR, MS.TEXT_COLOR AS STATUS_TEXT_COLOR, A.NAME AS ASSET_NAME
FROM MAINTENANCE_TASK M
LEFT OUTER JOIN MAINTENANCE_TYPE MT ON MT.ID_MAINTENANCE_TYPE = M.ID_TYPE
LEFT OUTER JOIN MAINTENANCE_STATUS MS ON MS.ID_MAINTENANCE_STATUS = M.ID_STATUS
LEFT OUTER JOIN ASSET A ON A.ID_ASSET = M.ID_ASSET
);

insert into verzije_baza
(id, dt_vpis, verzija, ver_nr, opis) values (1467, SYSDATE, '5.5', 1387, 'Maintenance')
;